require("ppmx")

##################################################################
# prepare
##################################################################

## prepare the data file:
Y0 <- read.table("dta.sim",header=T) # read 1000 simulated data records 
N <- nrow(Y0)
## now select a sub-sample of n=200 data points for the example
n <- 200                             # desired sample size
idx <- sample(1:N,n)
Yin <- Y0[idx,]

## parameters for posterior predictive inference
xgrid <- read.table("py-x.mdp")      # cov combinations for prediction
nx <- nrow(xgrid)                    # n of covariate combinations
ny <- 50                             # size of grid for prediction

##################################################################
# call ppmx
##################################################################

ppmx(Yin,n.discard=500,n.iter=3000,
     p0=1,                           # 1-dim response
     p1=1,p2=2,p4=0,                 # 1 cont and 2 categorical cov's
     B.prior=1,S.prior=1,n.batch=50,
     xgrid=xgrid)                    # request posterior pred inference

##################################################################
# some inference summaries
##################################################################

## read in some of the inference summaries
S <-   matrix(scan("py-S.mdp"),byrow=T,ncol=ny) # S is a (nx x ny) matrix
pdf <- matrix(scan("py-p.mdp"),byrow=T,ncol=ny) # pdf    (nx x ny) matrix
ygrid <- scan("py-y.mdp")                       # grid for predictive
nx <- nrow(xgrid)

matplot(ygrid,t(S),type="l",xlab="Y",ylab="SURVIVAL BY COVARIATE",
        bty="l")
legend(x=80,y=max(S),col=0:nx,lty=0:nx,
       legend=
       c("COVARIATES",paste(xgrid[,1],xgrid[,2],xgrid[,3],sep="\t")),
       bty="n",cex=0.5)

matplot(ygrid,t(pdf),type="l",xlab="Y",ylab="DIST BY COVARIATE",
        bty="l")
legend(x=80,y=max(pdf),col=0:nx,lty=0:nx,
       legend=
       c("COVARIATES",paste(xgrid[,1],xgrid[,2],xgrid[,3],sep="\t")),
       bty="n",cex=0.5)

## some summaries of the random clustering
## report on clustering of the first n0=50 data points
n0 <- 50
y <- Yin[1:n0,1]
X <- Yin[1:n0,2:4]                  # covariates
s <- read.table("member.mdp")[,2+(1:n0)]
     ## drop first two columns (it n, n clusters) and select first n0
M <- nrow(s)                        # n saved MC imputations
## empirical frquencies of pair-wise co-clustering
idx <- order(y)
sij <- matrix(0,nrow=n0,ncol=n0)
for(i in 1:(n0-1))
  for(j in (i+1):n0)
    sij[i,j] <- sum(s[,idx[i]]==s[,idx[j]])/M
for(i in 1:n0) sij[i,i] <- 1
image(sij,col=grey((1:12)/12))

## now try after ordering by covariates
idx <- order(X[,2],X[,3],X[,1])
sij <- matrix(0,nrow=n0,ncol=n0)
for(i in 1:(n0-1))
  for(j in (i+1):n0)
    sij[i,j] <- sum(s[,idx[i]]==s[,idx[j]])/M
for(i in 1:n0) sij[i,i] <- 1
image(sij,col=grey((1:12)/12))

## track cluster membership by iteration
image(1:n0,1:M,as.matrix(t(s)), col=rainbow(12),
      xlab="OBSERV",ylab="ITERATION")

pltS(idx=1:12,plt="p",lgd=T)          # plot post pred pdf
pltS(idx=1:12,plt="h")                # ... hazard
pltS(idx=1:12,plt="S",lgd=T)          # ... survival

pltS(idx=1:2,sd=T,plt="S",lgd=T)      # with pointwise post pred sd
