\name{ppmx-package}
\alias{ppmx-package}
\docType{package}
\title{
  Random partition model with covariates.
}
\description{
  The package implements posterior inference for the PPMx model.
  The PPMx model is an extension of the product partition model to
  include a regression on covariates.
}
\details{
  \tabular{ll}{
    Package: \tab ppmx\cr
    Type: \tab Package\cr
    Version: \tab 1.0\cr
    Date: \tab 2007-04-01\cr
    License: \tab GNU public domain software.\cr
  }
  The function \code{ppmx} implements posterior MCMC simulation for the
  PPMx model assuming a normal sampling model and the random partition
  model of the Dirichlet process prior (Polya urn) as the underlying PPM.
  The function \code{pltS} plots posterior predictive inference
  summaries. 

  The package uses the model described in \cite{Mueller, Quintana and Rosner (2008)}.
  Let \eqn{p(y_i \mid \rho, \mu,V) = N(\mu_i,V_i)} denote the observed
  responses for experimental units $i=1,\ldots,n$. Here
  \eqn{\rho=\{S_1,\ldots,S_k\}} is a random partition of the experimental
  units, \eqn{(\mu_i,V_i) = (\mu^\star_j,V^\star_j)} for
  all \eqn{i \in S_j} and \eqn{(\mu^star_j,V^\star_j) \sim G^\star},
  i.i.d.
  We model the random partition \eqn{\rho} as a PPM model with an
  additional similarity function. Let \eqn{x^\star_j=(x_i,\;i\in S_j)}
  denote the covariates arranged by clusters and let \eqn{g(x^star_j)}
  denote a function that formalizes similarity of a set of covariates
  (similarity function). Let \eqn{c(S_j) = M (|S_j|-1)!} denote the cohesion
  function implied by a Dirichlet process prior with total mass parameter
  \eqn{M}. 
  We assume
  \deqn{
    p(\rho) \propto \prod c(S_j) g(x^\star_j).
  }

  The base measure \eqn{G^star} is chosen conjugate to the normal sampling model,
  \eqn{G^\star(\mu,V^{-1})=G_{\mu}^\star(\mu) G_{V}^\star(V^{-1})} where
  \deqn{
    G_{\mu}^\star(\mu) = N(m,B) \mbox{ and } G_{V}^\star(V^{-1})=Wishart(s,(sS)^{-1}).
  }
  The Wishart distribution is parametrized such that \eqn{E(V_{-1})=S^{-1}}.
  We assume conjugate hyperpriors
  \deqn{
    m \sim N(a,A), B^{-1} \sim Wishart(c,(cC)^{-1}),
    S \sim Wishart(q, R/q).
  }
  The model is completed with a Gamma prior for the total mass paramter
  \eqn{\alpha \sim Ga(a_0,b_0)}.
}

\author{Peter Mueller, Maintainer: Peter Mueller \email{pm@wotan.mdacc.tmc.edu}}
\references{
  M\"uller, P., Quintana, F, and Rosner, G. (2008),
  ``Bayesian Clustering with Regression'', Technical report
  \url{http://odin.mdacc.tmc.edu/~pm/} }
\keyword{ package }
\seealso{See also the package \code{\link{DPpackage}}, at

  \url{http://student.kuleuven.be/~s0166452/software.html}.
}
